==> eiffelstudio-18.11.10.2592.tar: F_code/C24/xm1178.c <==
/*
 * Code for class XM_XSLT_COMPILED_COMMENT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm1178.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XSLT_COMPILED_COMMENT}.make */
void F2050_20568 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_7_) = (EIF_REFERENCE) arg1;
	F1829_18357(Current);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_10_37_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {XM_XSLT_COMPILED_COMMENT}.item_type */
EIF_REFERENCE F2050_20569 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	Result = RTOSCF(17130,F1775_17130,(Current));
	if ((EIF_BOOLEAN)(Result != NULL)) {
	}
	RTLE;
	return Result;
}

/* {XM_XSLT_COMPILED_COMMENT}.display */
void F2050_20570 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLR(4,tr3);
	RTLIU(5);
	
	RTGC;
	tr1 = RTOSCF(8261,F1130_8261,(Current));
	tr2 = F1793_17670(Current, arg1);
	tr3 = RTMS_EX_H("xsl:comment",11,244406388);
	loc1 = F1115_8108(RTCW(tr1), tr2, tr3);
	tr1 = RTOSCF(349,F31_349,(RTCV(RTOSCF(4803,F947_4803,(Current)))));
	F1189_9518(RTCW(tr1), loc1);
	tr1 = RTOSCF(349,F31_349,(RTCV(RTOSCF(4803,F947_4803,(Current)))));
	F1188_9511(RTCW(tr1));
	F2047_20523(Current, (EIF_INTEGER_32) (arg1 + ((EIF_INTEGER_32) 1L)));
	RTLE;
}

/* {XM_XSLT_COMPILED_COMMENT}.type_check */
void F2050_20571 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	
	
	RTGC;
}

/* {XM_XSLT_COMPILED_COMMENT}.generate_tail_call */
void F2050_20572 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc8 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_CHARACTER_8 tc1;
	RTLD;
	
	RTLI(12);
	RTLR(0,loc5);
	RTLR(1,arg2);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,Current);
	RTLR(5,loc6);
	RTLR(6,loc7);
	RTLR(7,loc2);
	RTLR(8,loc3);
	RTLR(9,tr2);
	RTLR(10,tr3);
	RTLR(11,loc8);
	RTLIU(12);
	
	RTGC;
	RTCT0("attached a_context.transformer as l_context_transformer", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(RTCW(arg2) + _REFACS_5_);
	loc5 = tr1;
	if (EIF_TEST(loc5)) {
		RTCK0;
	} else {
		RTCF0;
	}
	loc1 = (EIF_REFERENCE) loc5;
	F2047_20531(Current, arg2);
	tr1 = *(EIF_REFERENCE *)(Current);
	loc6 = tr1;
	if (EIF_TEST(loc6)) {
		tr1 = F1829_18343(Current);
		ti4_1 = F1829_18342(Current);
		F1634_14272(loc6, tr1, ti4_1);
		F1635_14280(RTCW(loc1), loc6);
	} else {
		RTCT0("postcondition_of_expand_children", EX_CHECK);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_9_);
		loc7 = tr1;
		if (EIF_TEST(loc7)) {
			RTCK0;
		} else {
			RTCF0;
		}
		loc2 = (EIF_REFERENCE) loc7;
		loc4 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			if ((EIF_BOOLEAN)(loc4 == ((EIF_INTEGER_32) 0L))) break;
			tr1 = RTMS_EX_H("--",2,11565);
			loc4 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE, EIF_REFERENCE, EIF_INTEGER_32)) R4909[Dtype(loc2)-1084])(RTCW(loc2), tr1, ((EIF_INTEGER_32) 1L));
			if ((EIF_BOOLEAN)(loc4 != ((EIF_INTEGER_32) 0L))) {
				tr1 = RTOSCF(8261,F1130_8261,(Current));
				tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32)) R4939[Dtype(loc2)-1082])(RTCW(loc2), ((EIF_INTEGER_32) 1L), loc4);
				tr3 = RTMS_EX_H(" ",1,32);
				loc3 = F1115_8098(RTCW(tr1), tr2, tr3);
				tr1 = RTOSCF(8261,F1130_8261,(Current));
				ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc2)+ _LNGOFF_1_1_0_2_);
				tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32)) R4939[Dtype(loc2)-1082])(RTCW(loc2), (EIF_INTEGER_32) (loc4 + ((EIF_INTEGER_32) 1L)), ti4_1);
				loc2 = F1115_8108(RTCW(tr1), loc3, tr2);
			}
		}
		tb1 = '\0';
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc2)+ _LNGOFF_1_1_0_2_);
		if ((EIF_BOOLEAN) (ti4_1 > ((EIF_INTEGER_32) 0L))) {
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc2)+ _LNGOFF_1_1_0_2_);
			tc1 = *(EIF_CHARACTER_8 *)(eif_optimize_return = 1, (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R3555[Dtype(loc2)-812])(RTCW(loc2), ti4_1));
			tb2 = tc1 == (EIF_CHARACTER_8) '-';
			tb1 = tb2;
		}
		if (tb1) {
			tr1 = RTOSCF(8261,F1130_8261,(Current));
			tr2 = RTMS_EX_H(" ",1,32);
			loc2 = F1115_8108(RTCW(tr1), loc2, tr2);
		}
	}
	tb1 = *(EIF_BOOLEAN *)(RTCW(loc1)+ _CHROFF_33_0_);
	if ((EIF_BOOLEAN) !tb1) {
		RTCT0("a_comment /= Void", EX_CHECK);
		if ((EIF_BOOLEAN)(loc2 != NULL)) {
			RTCK0;
		} else {
			RTCF0;
		}
		RTCT0("attached a_context.current_receiver as l_current_receiver", EX_CHECK);
		tr1 = *(EIF_REFERENCE *)(RTCW(arg2) + _REFACS_1_);
		loc8 = tr1;
		if (EIF_TEST(loc8)) {
			RTCK0;
		} else {
			RTCF0;
		}
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE, EIF_INTEGER_32)) R11568[Dtype(loc8)-1656])(loc8, loc2, ((EIF_INTEGER_32) 0L));
	}
	RTLE;
}

/* {XM_XSLT_COMPILED_COMMENT}.compute_cardinality */
void F2050_20573 (EIF_REFERENCE Current)
{
	GTCX
	
	
	F1095_7883(Current);
}

void EIF_Minit1178 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C24/xm1178.c <==
/*
 * Code for class XM_XSLT_COMPILED_COMMENT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm1178.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XSLT_COMPILED_COMMENT}.make */
void F2056_20599 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_7_) = (EIF_REFERENCE) arg1;
	F1836_18404(Current);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_10_37_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {XM_XSLT_COMPILED_COMMENT}.item_type */
EIF_REFERENCE F2056_20600 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	Result = RTOSCF(17177,F1782_17177, (Current));
	if ((EIF_BOOLEAN)(Result != NULL)) {
	}
	RTLE;
	return Result;
}

/* {XM_XSLT_COMPILED_COMMENT}.display */
void F2056_20601 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLR(4,tr3);
	RTLIU(5);
	
	RTGC;
	tr1 = RTOSCF(8292,F1130_8292, (Current));
	tr2 = F1800_17717(Current, arg1);
	tr3 = RTMS_EX_H("xsl:comment",11,244406388);
	loc1 = F1115_8139(RTCW(tr1), tr2, tr3);
	tr1 = RTOSCF(349,F31_349, (RTCV(RTOSCF(4819,F947_4819, (Current)))));
	F1189_9549(RTCW(tr1), loc1);
	tr1 = RTOSCF(349,F31_349, (RTCV(RTOSCF(4819,F947_4819, (Current)))));
	F1188_9542(RTCW(tr1));
	F2054_20570(Current, (EIF_INTEGER_32) (arg1 + ((EIF_INTEGER_32) 1L)));
	RTLE;
}

/* {XM_XSLT_COMPILED_COMMENT}.type_check */
void F2056_20602 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	
	
	RTGC;
}

/* {XM_XSLT_COMPILED_COMMENT}.generate_tail_call */
void F2056_20603 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc8 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_CHARACTER_8 tc1;
	RTLD;
	
	RTLI(12);
	RTLR(0,loc5);
	RTLR(1,arg2);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,Current);
	RTLR(5,loc6);
	RTLR(6,loc7);
	RTLR(7,loc2);
	RTLR(8,loc3);
	RTLR(9,tr2);
	RTLR(10,tr3);
	RTLR(11,loc8);
	RTLIU(12);
	
	RTGC;
	RTCT0("attached a_context.transformer as l_context_transformer", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(RTCW(arg2) + _REFACS_5_);
	loc5 = tr1;
	if (EIF_TEST(loc5)) {
		RTCK0;
	} else {
		RTCF0;
	}
	loc1 = (EIF_REFERENCE) loc5;
	F2054_20578(Current, arg2);
	tr1 = *(EIF_REFERENCE *)(Current);
	loc6 = tr1;
	if (EIF_TEST(loc6)) {
		tr1 = F1836_18390(Current);
		ti4_1 = F1836_18389(Current);
		F1641_14319(loc6, tr1, ti4_1);
		F1642_14327(RTCW(loc1), loc6);
	} else {
		RTCT0("postcondition_of_expand_children", EX_CHECK);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_9_);
		loc7 = tr1;
		if (EIF_TEST(loc7)) {
			RTCK0;
		} else {
			RTCF0;
		}
		loc2 = (EIF_REFERENCE) loc7;
		loc4 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			if ((EIF_BOOLEAN)(loc4 == ((EIF_INTEGER_32) 0L))) break;
			tr1 = RTMS_EX_H("--",2,11565);
			loc4 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE, EIF_REFERENCE, EIF_INTEGER_32)) R4930[Dtype(RTCW(loc2))-1085])(loc2, tr1, ((EIF_INTEGER_32) 1L));
			if ((EIF_BOOLEAN)(loc4 != ((EIF_INTEGER_32) 0L))) {
				tr1 = RTOSCF(8292,F1130_8292, (Current));
				tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32)) R4960[Dtype(RTCW(loc2))-1082])(loc2, ((EIF_INTEGER_32) 1L), loc4);
				tr3 = RTMS_EX_H(" ",1,32);
				loc3 = F1115_8129(RTCW(tr1), tr2, tr3);
				tr1 = RTOSCF(8292,F1130_8292, (Current));
				ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc2)+ _LNGOFF_1_1_0_2_);
				tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32)) R4960[Dtype(RTCW(loc2))-1082])(loc2, (EIF_INTEGER_32) (loc4 + ((EIF_INTEGER_32) 1L)), ti4_1);
				tr1 = F1115_8139(RTCW(tr1), loc3, tr2);
				loc2 = (EIF_REFERENCE) tr1;
			}
		}
		tb1 = '\0';
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc2)+ _LNGOFF_1_1_0_2_);
		if ((EIF_BOOLEAN) (ti4_1 > ((EIF_INTEGER_32) 0L))) {
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc2)+ _LNGOFF_1_1_0_2_);
			tc1 = (eif_optimize_return = 1, *(EIF_CHARACTER_8 *)(FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R3562[Dtype(RTCW(loc2))-812])(loc2, ti4_1));
			tb2 = tc1 == (EIF_CHARACTER_8) '-';
			tb1 = tb2;
		}
		if (tb1) {
			tr1 = RTOSCF(8292,F1130_8292, (Current));
			tr2 = RTMS_EX_H(" ",1,32);
			tr1 = F1115_8139(RTCW(tr1), loc2, tr2);
			loc2 = (EIF_REFERENCE) tr1;
		}
	}
	tb1 = *(EIF_BOOLEAN *)(RTCW(loc1)+ _CHROFF_33_0_);
	if ((EIF_BOOLEAN) !tb1) {
		RTCT0("a_comment /= Void", EX_CHECK);
		if ((EIF_BOOLEAN)(loc2 != NULL)) {
			RTCK0;
		} else {
			RTCF0;
		}
		RTCT0("attached a_context.current_receiver as l_current_receiver", EX_CHECK);
		tr1 = *(EIF_REFERENCE *)(RTCW(arg2) + _REFACS_1_);
		loc8 = tr1;
		if (EIF_TEST(loc8)) {
			RTCK0;
		} else {
			RTCF0;
		}
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE, EIF_INTEGER_32)) R11599[Dtype(loc8)-1663])(loc8, loc2, ((EIF_INTEGER_32) 0L));
	}
	RTLE;
}

/* {XM_XSLT_COMPILED_COMMENT}.compute_cardinality */
void F2056_20604 (EIF_REFERENCE Current)
{
	GTCX
	
	
	F1095_7913(Current);
}

void EIF_Minit1178 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
